Revise
======


.. image:: https://travis-ci.org/rhyselsmore/revise.png?branch=master
        :target: https://travis-ci.org/rhyselsmore/revise

.. image:: https://pypip.in/d/revise/badge.png
        :target: https://crate.io/packages/revise/

Easily Transform and Validate JSON.

Installation
------------

.. code-block:: bash

    pip install revise

Contribute
----------

#. Check for open issues or open a fresh issue to start a discussion around a feature idea or a bug. There is a Contributor Friendly tag for issues that should be ideal for people who are not very familiar with the codebase yet.
#. Fork `the repository`_ on Github to start making your changes to the **master** branch (or branch off of it).
#. Write a test which shows that the bug was fixed or that the feature works as expected.
#. Send a pull request and bug the maintainer until it gets merged and published.

.. _`the repository`: http://github.com/rhyselsmore/revise